Module parse

Module parse 

Structs

Indices

Enums

ProgramId

Functions

event_from_light_transaction
We piece the event together from 2 instructions:
find_cpi_pattern
Pattern, SYSTEM_PROGRAM_ID.., default ids .., account compression program id We search for the pattern in reverse because there can be multiple system instructions but only one account compression instruction. Start index points to ACCOUNT_COMPRESSION_PROGRAM_ID
find_cpi_patterns
Filter all system instructions which create cpi context accounts, so that we can infer that a system program instruction is a light transaction. Create new AssociatedInstructions when we find a system instruction if next instruct is solana system program isntruction followed by insert into queues is executable instruction else is cpi instruction only push into vec if insert into queues instruction is found
wrap_program_ids