find_cpi_pattern

Function find_cpi_pattern 

pub fn find_cpi_pattern(
    start_index: usize,
    program_ids: &[ProgramId],
) -> (Option<Indices>, usize)
Pattern, SYSTEM_PROGRAM_ID.., default ids .., account compression program id We search for the pattern in reverse because there can be multiple system instructions but only one account compression instruction. Start index points to ACCOUNT_COMPRESSION_PROGRAM_ID