find_cpi_patterns

Function find_cpi_patterns 

pub fn find_cpi_patterns(program_ids: &[ProgramId]) -> Vec<Indices>
Filter all system instructions which create cpi context accounts, so that we can infer that a system program instruction is a light transaction. Create new AssociatedInstructions when we find a system instruction if next instruct is solana system program isntruction followed by insert into queues is executable instruction else is cpi instruction only push into vec if insert into queues instruction is found